@@ -82,6 +82,18 @@ def download_component(client: Client, data_service_id: str, dataflow_id: str, c
     f.write(rendered_component)
 
 
+def _rewrite_connection_ids_to_friendly_ids(connections: dict, dataflow: Dataflow):
+  cids_map = {x.id.value: x.entity_metadata.id for x in connections.data}
+  for c in dataflow.components:
+    # for transform, there is no container.
+    cid = c.container.record_connection.connection_id.value if hasattr(c, 'container') else None
+    # backword compatible change, if use new sdk against old env, we may get into a case that
+    # uuid to friendly map get an empty mapping value.
+    friendly_id = cids_map.get(cid) if cid else None
+    if friendly_id:
+      c.container.record_connection.connection_id.value = friendly_id
+
+
 def download_dataflow(client: Client, data_service_id: str, dataflow_id: str, resource_base_path: str = "."):
   """
   Downloads a Dataflow and writes its definition to a file named `{dataflow_id}.py` under
@@ -106,15 +118,8 @@ def download_dataflow(client: Client, data_service_id: str, dataflow_id: str, re
 
   # translate connection id to friendly id
   connections = client.list_connections(data_service_id)
-  cids_map = {x.id.value: x.entity_metadata.id for x in connections.data}
-  for c in dataflow.components:
-    # for transform, there is no container.
-    cid = c.container.record_connection.connection_id.value if hasattr(c, 'container') else None
-    # backword compatible change, if use new sdk against old env, we may get into a case that
-    # uuid to friendly map get an empty mapping value.
-    friendly_id = cids_map.get(cid) if cid else None
-    if friendly_id:
-      c.container.record_connection.connection_id.value = friendly_id
+
+  _rewrite_connection_ids_to_friendly_ids(connections, dataflow)
 
   dataflow_resource_path = os.path.join(resource_base_path, f"{dataflow.id}")
   dataflow_path = os.path.join(resource_base_path, f"{dataflow.id}.py")
@@ -150,6 +155,9 @@ def download_data_service(client: Client, data_service_id: str, resource_base_pa
 
   ds_proto = client.get_data_service(data_service_id=data_service_id).data
   data_service = data_service_from_proto(client, ds_proto)
+  connections = client.list_connections(data_service_id)
+  for dataflow in data_service.dataflows:
+    _rewrite_connection_ids_to_friendly_ids(connections, dataflow)
   write_data_service(client.hostname, data_service, resource_base_path)
 
 
